<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Category;
use App\Models\ChildCategory;
use App\Models\GrandChildCategory;
use Intervention\Image\ImageManager;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;
use File;
use Illuminate\Support\Facades\Validator;
class CategoryController extends Controller
{
    public function index()
    {
    $categories = Category::all();
    $childcategories = ChildCategory::all();
    return view('Admin.Category.index',compact('categories','childcategories'));
    }
    public function get_category()
    {
    $categories = Category::orderByDesc('id')->get();
    return response()->json(['data' => $categories, 'status' => 'success']);
    }
    public function store(Request $request)
    {
    $validated_data = $request->validate([
        'title' => 'required|string',
        'sku' => 'required|string|unique:categories,sku',
        'thumbnail_image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
        'cover_image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
    ]);
    Storage::makeDirectory('public/categories');
    if ($request->hasFile('thumbnail_image')) {
        $image = $request->file('thumbnail_image');
        $thumbnailName = 'thumb_' . time() . '.' . $image->getClientOriginalExtension();
        $image->move(public_path('temp'), $thumbnailName);
        $manager = new ImageManager();
        $optimizedImage = $manager->make(public_path('temp') . '/' . $thumbnailName)
            ->fit(800, 500)
            ->encode();
        $optimizedImage->save(public_path('categories') . '/' . $thumbnailName);
        unlink(public_path('temp') . '/' . $thumbnailName);
        $validated_data['thumbnail_image'] = 'categories/' . $thumbnailName;
    }
    if ($request->hasFile('cover_image')) {
        $image = $request->file('cover_image');
        $coverName = 'cover_' . time() . '.' . $image->getClientOriginalExtension();
        $image->move(public_path('temp'), $coverName);
        $manager = new ImageManager();
        $optimizedImage = $manager->make(public_path('temp') . '/' . $coverName)
            ->fit(1920, 700)
            ->encode();
        $optimizedImage->save(public_path('categories') . '/' . $coverName);
        unlink(public_path('temp') . '/' . $coverName);
        $validated_data['cover_image'] = 'categories/' . $coverName;
    }
    $brand = Category::create($validated_data);
    }
    public function delete(Request $request)
    {
    $id = $request->id;
    $category = Category::find($id);
    if ($category) {
        $category->delete(); // Delete the record
        return response()->json(['status' => 'success', 'message' => 'Category has been deleted.']);
    } else {
        return response()->json(['status' => 'error', 'message' => 'Category not found.']);
    }
    }
    public function edit_category(Request $request)
    {
    $id = $request->id;
    $cat = Category::find($id);
    return response()->json($cat);
    }
    public function show_category_detail(Request $request)
    {
    $id = $request->id;
    $cat = Category::find($id);
    return response()->json($cat);
    }
    public function update_category(Request $request, $id)
    {
    // Validate the incoming request data
    $validator = Validator::make($request->all(), [
        'title' => 'required|string',
        'sku' => 'required|string|unique:categories,sku,' . $id,
        'thumbnail_image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
        'cover_image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
    ]);
    // Check for validation errors
    if ($validator->fails()) {
        return response()->json(['status' => 'error', 'message' => $validator->errors()], 422);
    }
    // Find the category to update
    $category = Category::find($id);
    if (!$category) {
        return response()->json(['status' => 'error', 'message' => 'Category not found.'], 404);
    }
    // Initialize an empty array to hold the image data
    $validated_data = [];
    // Process and update thumbnail image
    if ($request->hasFile('thumbnail_image')) {
        $thumbnailImage = $request->file('thumbnail_image');
        $thumbnailImageName = time() . '.' . $thumbnailImage->getClientOriginalExtension();
        $thumbnailImage->move(public_path('categories'), $thumbnailImageName);
        $validated_data['thumbnail_image'] = 'categories/' . $thumbnailImageName;
    }
    // Process and update cover image
    if ($request->hasFile('cover_image')) {
        $coverImage = $request->file('cover_image');
        $coverImageName = time() . '.' . $coverImage->getClientOriginalExtension();
        $coverImage->move(public_path('categories'), $coverImageName);
        $validated_data['cover_image'] = 'categories/' . $coverImageName;
    }
    // If neither thumbnail_image nor cover_image was uploaded, do not include it in the update
    if (!$request->hasFile('thumbnail_image') && !$request->hasFile('cover_image')) {
        $category->update($validator->validated());
    } else {
        // Update the category with validated data (including images)
        $category->update(array_merge($validator->validated(), $validated_data));
    }
    return response()->json(['status' => 'success', 'message' => 'Category updated successfully.']);
    }

// child category functions
    public function store_child_category(Request $request)
    {
    $validatedData = $request->validate([
        'main_parent_category' => 'required|integer', 
        'child_sku' => 'required|string|unique:child_categories,child_sku',
        'child_title' => 'required|string',
    ]);
    try {
        ChildCategory::create($validatedData);
        return response()->json(['status' => 'success', 'message' => 'Child Category Added Successfully.']);
    } catch (ValidationException $e) {
        return response()->json(['status' => 'error', 'message' => 'SKU already exists.'], 422);
    }
    }
    public function get_child_category()
    {
        $categories = Category::join('child_categories', 'categories.id', '=', 'child_categories.main_parent_category')->orderByDesc('id')
        ->select('categories.title', 'child_categories.*')
        ->get();
        return response()->json(['data' => $categories, 'status' => 'success']);
    }
    public function delete_child_catgory(Request $request)
    {
        $id = $request->id;
        $category = ChildCategory::find($id);
        if ($category) {
            $category->delete(); // Delete the record
            return response()->json(['status' => 'success', 'message' => 'Category has been deleted.']);
        } else {
            return response()->json(['status' => 'error', 'message' => 'Category not found.']);
        }
    }
    public function edit_child_category(Request $request)
    {
        $id = $request->id;
        $chil_category_data = Category::join('child_categories', 'categories.id', '=', 'child_categories.main_parent_category')
        ->select('categories.title', 'child_categories.*')
        ->where('child_categories.id', $id)
        ->get();
        return response()->json($chil_category_data);
    }
    public function update_child_category(Request $request, $id)
    {
        $validatedData = $request->validate([
            'main_parent_category' => 'required|integer', 
            'child_title' => 'required|string',
            'child_sku' => 'required|string|unique:child_categories,child_sku,'.$id,    
        ]);
        $childCategory = ChildCategory::findOrFail($id);
        $childCategory->update($validatedData);
        return response()->json(['status' => 'success', 'message' => 'Child Category Updated Successfully.']);
    }
    public function show_child_detail(Request $request)
    {
        $id = $request->id;
        $child = Category::join('child_categories', 'categories.id', '=', 'child_categories.main_parent_category')
        ->select('categories.title', 'child_categories.*')
        ->where('child_categories.id', $id)
        ->get();
        return response()->json($child);
    }

// Grand child category functions
    public function store_grandchild_category(Request $request)
    {
        $validatedData = $request->validate([
            'mid_parent_category' => 'required|integer',
            'grand_title' => 'required|string', 
            'grand_sku' => 'required|string|unique:grand_child_categories,grand_sku',
            
        ]);
        try {
            GrandChildCategory::create($validatedData);
            return response()->json(['status' => 'success', 'message' => 'Child Category Added Successfully.']);
        } catch (ValidationException $e) {
            return response()->json(['status' => 'error', 'message' => 'SKU already exists.'], 422);
        }
    } 
    public function get_grandchild_category()
    {
        $categories  = ChildCategory::join('grand_child_categories', 'child_categories.id', '=', 'grand_child_categories.mid_parent_category')->orderByDesc('id')
        ->select('child_categories.child_title', 'grand_child_categories.*')
        ->get();
        return response()->json(['data' => $categories, 'status' => 'success']);
    }
    public function delete_grandchild_catgory(Request $request)
    {
        $id = $request->id;
        $category = GrandChildCategory::find($id);
        if ($category) {
            $category->delete(); // Delete the record
            return response()->json(['status' => 'success', 'message' => 'Category has been deleted.']);
        } else {
            return response()->json(['status' => 'error', 'message' => 'Category not found.']);
        }
    }
    public function edit_grandchild_category(Request $request)
    {
        $id = $request->id;
        $chil_category_data = GrandChildCategory::join('child_categories', 'child_categories.id', '=', 'grand_child_categories.mid_parent_category')
        ->select('child_categories.child_title', 'grand_child_categories.*')
        ->where('grand_child_categories.id', $id)
        ->get();
        return response()->json($chil_category_data);
    
    }
    public function update_grandchild_category(Request $request, $id)
    {
        $validatedData = $request->validate([
            'mid_parent_category' => 'required|integer', 
            'grand_title' => 'required|string',
            'grand_sku' => 'required|string|unique:child_categories,child_sku,'.$id,
        ]);
        $childCategory = GrandChildCategory::findOrFail($id);
        $childCategory->update($validatedData);
        return response()->json(['status' => 'success', 'message' => 'Child Category Updated Successfully.']);
    }
    public function show_grandchild_detail(Request $request)
    {
        $id = $request->id;
        $grandchild = GrandChildCategory::join('child_categories', 'child_categories.id', '=', 'grand_child_categories.mid_parent_category')
        ->select('child_categories.child_title', 'grand_child_categories.*')
        ->where('grand_child_categories.id', $id)
        ->get();
        return response()->json($grandchild);
    
    }

}
