<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Product;
use App\Models\User;
use App\Models\Invoices;
use Illuminate\Support\Facades\Auth;
use DB;
use App\Http\Controllers\Admin\Traits\InvoiceTrait;
use App\Models\GeneralSettings;
use App\General\GeneralSettingsClass;
use PDF;

class InvoiceController extends Controller
{
    use InvoiceTrait;

    public function index(Request $request)
    {
        $users = User::all();
        $roles = DB::table('roles')->get();

        $limit = 50;
        if ($request->get('records_limit') && !empty($request->get('records_limit'))) {
            $limit = $request->get('records_limit');
            if ($request->get('payment_status') && !empty($request->get('payment_status'))) {

                if ($request->get('payment_method') && !empty($request->get('payment_method')) && $request->get('payment_status') && !empty($request->get('payment_status'))) {
                    #Payment Status and Payment Method
                    $status = $request->get('payment_status');
                    $method = $request->get('payment_method');
                    $invoices = Invoices::where('is_deleted', 0)->where('payment_method', $method)->where('payment_status', $status)->limit($limit)->orderBy('id', 'DESC')->get();
                    return view('Admin.Invoices.index', compact('users', 'roles', 'invoices'));
                } else {
                    #Payment Status
                    $status = $request->get('payment_status');
                    $invoices = Invoices::where('is_deleted', 0)->where('payment_status', $status)->limit($limit)->orderBy('id', 'DESC')->get();
                    return view('Admin.Invoices.index', compact('users', 'roles', 'invoices'));
                }
            } else if ($request->get('payment_method') && !empty($request->get('payment_method'))) {
                #Payment Method
                $method = $request->get('payment_method');
                $invoices = Invoices::where('is_deleted', 0)->where('payment_method', $method)->limit($limit)->orderBy('id', 'DESC')->get();
                return view('Admin.Invoices.index', compact('users', 'roles', 'invoices'));
            } else {
                $invoices = Invoices::where('is_deleted', 0)->limit($limit)->orderBy('id', 'DESC')->get();
                return view('Admin.Invoices.index', compact('users', 'roles', 'invoices'));
            }
        } else {
            $invoices = Invoices::where('is_deleted', 0)->limit($limit)->orderBy('id', 'DESC')->get();
            return view('Admin.Invoices.index', compact('users', 'roles', 'invoices'));
        }
    }

    public function create()
    {
        $users = User::all();
        $roles = DB::table('roles')->get();

        $logged_in_user = Auth::user();

        $invoice = new Invoices();
        $invoice->created_by = $logged_in_user->id;
        $invoice->save();
        $Invoice_review = $this->ReviewInvoice($invoice->id);
        return view('Admin.Invoices.create', compact('users', 'roles', 'invoice', 'Invoice_review'));
    }
    public function edit(Invoices $invoice)
    {
        $users = User::all();
        $roles = DB::table('roles')->get();
        $plans_list = [];
        if ($invoice->customer_type == 'existing') {
            $customer_id = $invoice->customer;
            $plans_list = DB::table('membership_subscriptions')
                ->join('membership_plans', 'membership_subscriptions.plan_id', '=', 'membership_plans.id')
                ->where('membership_subscriptions.customer_id', $customer_id)
                ->where('membership_subscriptions.expired', 0)
                ->get();
        }
        $Invoice_review = $this->ReviewInvoice($invoice->id);
        return view('Admin.Invoices.edit', compact('users', 'roles', 'invoice', 'Invoice_review', 'plans_list'));
    }
    public function destroy($id)
    {
        $invoice = Invoices::find($id);
        if (!$invoice) {
            return response()->json(['error' => 'Invoice not found'], 404);
        }
        try {
            $invoice->delete();
            DB::table('invoices_meta')->where('invoice_id', $invoice->id)->delete();
        } catch (\Exception $e) {
            return response()->json(['error' => 'Failed to delete the invoice'], 500);
        }
        return response()->json(['message' => 'Invoice deleted successfully']);
    }

    public function is_delete($id)
    {
        $invoice = Invoices::findOrFail($id);
        $invoice->is_deleted = 1;
        $invoice->save();
        return response()->json(['message' => 'Invoice deleted successfully'], 200);
    }

    public function searchProducts(Request $request)
    {
        $search_query = $request->get('query');

        $products = Product::where('title', 'like', "%$search_query%")
            ->orWhere('sku', 'like', "%$search_query%")
            ->get();

        if (sizeof($products) > 0) {
            return response()->json(['products' => $products]);
        } else {
            $check_upc = DB::table('products_meta')
                ->where('option', '=', '_upc')
                ->where('value', 'like', "%$search_query%")
                ->pluck('product_id'); # Use pluck() to get an array of product_ids
            return response()->json(['products' => Product::findMany($check_upc)]);
        }
    }
    public function selectProduct(Request $request)
    {
        $product_details = Product::find($request->get('product_id'));
        $product_meta = DB::table('products_meta')->where('product_id', '=', $request->get('product_id'))->where('option', '=', '_price')->first();

        return response()->json(['product' => $product_details, 'meta' => $product_meta]);
    }
    public function update(Request $requestData, $id)
    {
        try {
            $invoice = Invoices::findOrFail($id);
            $invoice->customer_type = $requestData['customer_type'];
            $invoice->customer = $requestData['customer'];
            $invoice->total_units = $requestData['total_units'];
            $invoice->sub_total = $requestData['sub_total'];
            $invoice->discount = $requestData['discount'];
            $invoice->discounted_amount = $requestData['discounted_amount'];
            $invoice->gst = $requestData['gst'];
            $invoice->grand_total = $requestData['grand_total'];
            $invoice->invoice_date = $requestData['invoice_date'];
            $invoice->due_date = $requestData['due_date'];
            $invoice->active = $requestData['active'];
            $invoice->payment_status = $requestData['payment_status'];
            $invoice->payment_method = $requestData['payment_method'];
            $invoice->payment_id = $requestData['payment_id'];
            $invoice->plan_id = $requestData['plan_id'];
            $invoice->membership_dicount = $requestData['membership_dicount'];
            $invoice->membership_dicounted_total = $requestData['membership_dicounted_total'];
            $invoice->membership_discount_percentage = $requestData['membership_discount_percentage'];
            $invoice->save();

            DB::table('invoices_meta')->where('invoice_id', $id)->delete();

            for ($i = 0; $i < count($requestData['product_id']); $i++) {
                $item_array = [
                    'invoice_id' => $id,
                    'invoice_number' => $invoice->invoice_number,
                    'product_id' => $requestData['product_id'][$i],
                    'product_name' => $requestData['product_name'][$i],
                    'units' => $requestData['units'][$i],
                    'unit_price' => $requestData['unit_price'][$i],
                    'unit_total_price' => $requestData['unit_total_price'][$i],
                ];
                DB::table('invoices_meta')->insert($item_array);
            }
            if ($invoice->active == 1) {
                $this->update_quantity($id);
            }
            $Invoice_review = $this->ReviewInvoice($id);
            return response()->json(['message' => 'Invoice updated successfully', 'invoice_review' => $Invoice_review], 200);
        } catch (\Exception $e) {
            return response()->json(['error' => 'Error updating invoice: ' . $e->getMessage()], 500);
        }
    }
    public function generatePdf($id)
    {
        $Invoice_review = $this->ReviewInvoice($id);
        return response()->json(['message' => 'Invoice updated successfully', 'invoice_review' => $Invoice_review], 200);
    }
    public function update_quantity($inovice_id)
    {
        $get_invoice_items = DB::table('invoices_meta')->where('invoice_id', $inovice_id)->get();
        foreach ($get_invoice_items as $get_invoice_item) {

            $product_meta = DB::table('products_meta')->where('product_id', $get_invoice_item->product_id)->where('option', '_stock')->first();
            $invoice_quantity = $get_invoice_item->units;
            $product_stock = $product_meta->value;
            $updated_stock = $product_stock - $invoice_quantity;
            DB::table('products_meta')->where('product_id', '=', $get_invoice_item->product_id)->where('option', '=', '_stock')->update(['value' => $updated_stock]);
        }
    }
}
