<?php

namespace App\Http\Controllers\Website;

use App\General\GeneralSettingsClass;
use App\Http\Controllers\Controller;
use App\Http\Controllers\Website\EmailController;
use App\Models\User;
use DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Str;

class AuthController extends Controller
{
    public function login(Request $request)
    {
        $credentials = $request->validate([
            'email' => 'required|email',
            'password' => 'required',
        ], [
            'email.required' => 'The email field is required.',
            'email.email' => 'Please enter a valid email address.',
            'password.required' => 'The password field is required.',
        ]);

        if (Auth::attempt($credentials)) {
            $request->session()->regenerate();
            return redirect()->route('Website.GeneralPages.Profile');
        }
        return redirect()->back()->with(['status' => 'false', 'message' => 'The provided credentials do not match our records.']);
    }

    public function logout()
    {
        Auth::logout();
        return redirect('/');
    }

    public function sendResetLinkEmail(Request $request)
    {
        try {
            $request->validate([
                'email' => 'required|email',
            ]);
            $user = User::where('email', $request->email)->exists();
            $data = GeneralSettings::where('option', '_header_logo')->orWhere('option', '_b_email')->orWhere('option', '_instagram_link')->orWhere('option', '_facebook_link')->orWhere('option', '_twitter_link')->orWhere('option', '_youtube_link')->get()->toArray();

            $admin_email_index = array_search('_b_email', array_column($data, 'option'));
            $header_logo_index = array_search('_header_logo', array_column($data, 'option'));
            $insta_link_index = array_search('_instagram_link', array_column($data, 'option'));
            $fb_link_index = array_search('_facebook_link', array_column($data, 'option'));
            $twitter_link_index = array_search('_twitter_link', array_column($data, 'option'));
            $youtube_link_index = array_search('_youtube_link', array_column($data, 'option'));

            $admin_email = $data[$admin_email_index]['value'];
            $logo = $data[$header_logo_index]['value'];
            $instagram_link = $data[$insta_link_index]['value'];
            $facebook_link = $data[$fb_link_index]['value'];
            $twitter_link = $data[$twitter_link_index]['value'];
            $youtube_link = $data[$youtube_link_index]['value'];

            if ($user) {
                // Delete previous password reset request if exists for this email
                DB::table('password_resets')->where('email', $request->email)->delete();

                $user_details = User::where('email', $request->email)->first();
                $token = Str::random(60);
                $expiration = now()->addMinutes(env('PASSWORD_LINK_TIME'));

                DB::table('password_resets')->insert([
                    'email' => $request->email,
                    'token' => $token,
                    'created_at' => now(),
                    'expires_at' => $expiration,
                ]);
                $resetUrl = URL::signedRoute('Website.ResetPassword', ['token' => $token]);
                $params = [
                    'subject' => 'Reset Password Email | ' . config('app.website_name'),
                    'to' => $user_details->email,
                    'blade' => 'reset-password',
                    'data' => [
                        'name' => $user_details->name,
                        'url' => $resetUrl,
                        'logo' => $logo,
                        'instagram_link' => $instagram_link,
                        'facebook_link' => $facebook_link,
                        'twitter_link' => $twitter_link,
                        'youtube_link' => $youtube_link,
                        'admin_email' => $admin_email,
                    ],
                ];

                $emailController = new EmailController();
                $emailSent = $emailController->SendInstantEmail($params);
                if ($emailSent) {
                    return redirect()->back()->with(['status' => 200, 'message' => 'An Reset Password Email has been sent to your Email.']);
                } else {
                    return redirect()->back()->with(['status' => 500, 'message' => 'SMTP is not Working, Try Later!']);
                }
            } else {
                return redirect()->back()->with(['status' => 404, 'message' => 'Account with the entered does not exist.']);
            }
        } catch (Exception $ex) {
            return response()->json([
                'status' => 500,
                'message' => 'An Error Occured, Try Again!',
                'error' => $ex,
            ]);
        }
    }

    public function updatePassword(Request $request, $token = null)
    {
        $request->validate([
            'token' => 'required',
            'password' => 'required|confirmed|min:8',
        ]);

        $reset = DB::table('password_resets')
            ->where('token', $request->token)
            ->where('expires_at', '>', now())
            ->first();

        if (!$reset) {
            return redirect()->back()->with(['status' => 404, 'message' => 'Invalid or Expired Reset Password Link!']);
        }
        $email = $reset->email;
        $user = User::where('email', $email)->first();
        $user->password = Hash::make($request->password);
        $user->save();

        DB::table('password_resets')->where('email', $email)->delete();

        $params = [
            'subject' => 'Password Reset Successfully | ' . config('app.website_name'),
            'to' => $user->email,
            'blade' => 'update-password',
            'data' => [
                'name' => $user->name,
                'url' => url('/'),
            ],
        ];
        $emailController = new EmailController();
        $emailSent = $emailController->SendInstantEmail($params);
        if ($emailSent) {
            return redirect()->route('Website.GeneralPages.Login')->with(['status' => 200, 'message' => 'Password Updated Successfully. You can now login to your account']);
        } else {
            return redirect()->route('Website.GeneralPages.Login')->with(['status' => 200, 'message' => 'Password Updated, SMTP ERROR occurred while sending email!']);
        }
    }
}
