<?php

namespace App\Http\Controllers\Website;

use App\General\GeneralSettingsClass;
use App\Http\Controllers\Controller;
use App\Models\GeneralSettings;
use App\Models\GiftCard;
use App\Models\GiftCardPurchases;
use App\Models\GiftCardUsed;
use App\Models\UserAddress;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;

class CartController extends Controller
{
    public function cart_details()
    {
        $percentage = config('app.PERCENTAGE');
        $meta_details = [
            'title' => 'Cart | ToolTrade',
            'keywords' => 'donate, donation, charity, ToolTrade, organization',
            'description' => 'Support our cause by making a donation to ToolTrade. Together, we can make a difference in the lives of those in need.',
            'author' => 'ToolTrade Org',
        ];
        $cartData = $updatedCartData = session('cartData', []);
        $totalAmount = session('totalAmount', 0);
        $totalItems = session('total_items', 0);
        $subTotal = session('subTotal', 0);
        $totalGst = session('totalGst', 0);
        return view('Website.GeneralPages.shopping-cart', get_defined_vars());
    }

    public function checkout_page()
    {
        $couponArray = session()->get('coupon_array');
        if ($couponArray) {
            $totalAmount = $couponArray['old_totalAmount'];
            session(['totalAmount' => $totalAmount]);
        }
        Session::forget('coupon_array');
        
        $meta_details = [
            'title' => 'Checkout | ToolTrade',
            'keywords' => 'donate, donation, charity, ToolTrade, organization',
            'description' => 'Support our cause by making a donation to ToolTrade. Together, we can make a difference in the lives of those in need.',
            'author' => 'ToolTrade Org',
        ];
        $cartData = session('cartData', []);
        $totalAmount = session('totalAmount', 0);
        $totalItems = session('total_items', 0);
        $subTotal = session('subTotal', 0);
        $totalGst = session('totalGst', 0);
        $userType = "guest";

        $user = Auth::user();
        $addresses = UserAddress::where('user_id', Auth::id())->where('address_type', '!=', 'default shipping')->get();
        $plans = DB::table('membership_subscriptions')->where('customer_id', Auth::id())->where('expired', 0)
            ->join('membership_plans as plan', 'membership_subscriptions.plan_id', '=', 'plan.id')
            ->get();
        if ($user) {
            $userType = "authenticated";
            $auth_discount_per = GeneralSettingsClass::getRequiredValue('_auth_discount_percentage');
            $auth_discount = round($auth_discount_per, 2) / 100;
            $discount_from_amount = round($totalAmount, 2) - round($totalGst, 2);
            $apply_discount = $discount_from_amount * $auth_discount;
            $discounted_amount = round($discount_from_amount, 2) - round($apply_discount, 2);
            session(['authDisount' => $apply_discount]);
            session(['authDiscountPer' => $auth_discount_per]);
        } else {
            $apply_discount = 0;
            $authDiscountPer = 0;
            $discounted_amount = $totalAmount;
            session(['authDisount' => $apply_discount]);
            session(['authDiscountPer' => $authDiscountPer]);
            $userType = "guest";
        }
        return view('Website.GeneralPages.new-checkout', get_defined_vars());
    }

    public function fetch_shipping_address($id)
    {
        $address = UserAddress::where('id', $id)->first();
        return response()->json($data = $address);
    }
    
    public function apply_coupon(Request $request)
    {
        $giftcard = GiftCard::where('coupon_code', $request->code)->first();
        $giftCardPurchases = GiftCardPurchases::where('coupon_code', $request->code)->with('card')->first();
        $today = Carbon::today();
        if ($giftcard) {
            $issue_date = $giftcard->start_date;
            $expiry_date = $giftcard->end_date;
            $is_expirable = $giftcard->is_expirable;
            $is_expired = $giftcard->is_expired;
            $is_deleted = $giftcard->is_deleted;
            $usage = $giftcard->usage;

            if ($usage == 'one_time') {
                $used_card = GiftCardUsed::where('card_id', $giftcard->id)->first();
                if (!$user_card) {
                    if ($is_expired == 0) {
                        if ($is_deleted == 0) {
                            if ($today->greaterThanOrEqualTo($issue_date) && $today->lessThanOrEqualTo($expiry_date)) {
                                $discount = $giftcard->discount;
                                $couponRemaining = 0;
                                $amountPaidByCoupon = 0;
                                $totalAmount = $request->session()->get('totalAmount');
                                $discountedAmount = $totalAmount - $discount;
                                if ($discountedAmount < 0) {
                                    $discountedAmount = 0;
                                    $amountPaidByCoupon = $totalAmount;
                                    $couponRemaining = $discount - $totalAmount;
                                } else {
                                    $couponRemaining = 0;
                                    $amountPaidByCoupon = $totalAmount - $discountedAmount;
                                }

                                $couponArray = ['old_totalAmount' => $totalAmount, 'couponRemaining' => $couponRemaining, 'cardId' => $giftcard->id, 'card_amount' => $giftcard->discount, 'amountPaidByCoupon' => $amountPaidByCoupon];
                                session(['totalAmount' => $discountedAmount]);
                                session(['coupon_array' => $couponArray]);


                                return response(['status' => true, 'code' => 200, 'message' => 'Valid Coupon', 'data' => $discount, 'grandTotal' => $discountedAmount, 'couponRemaining' => $couponRemaining]);
                            } elseif ($today->lessThan($issue_date)) {
                                return response(['status' => false, 'code' => 302, 'message' => 'This coupon is no yet available.', 'start_date' => $issue_date]);
                            } else {
                                return response(['status' => false, 'code' => 302, 'message' => 'This coupon is no longer available.']);
                            }
                        } else {
                            return response(['status' => false, 'code' => 302, 'message' => 'This coupon is no longer available.']);
                        }
                    } else {
                        return response(['status' => false, 'code' => 302, 'message' => 'This Coupon is expired.']);
                    }
                } else {
                    return response(['status' => false, 'code' => 302, 'message' => 'This Coupon is expired.']);
                }
            } elseif ($usage == 'one_time_per_user') {
                $user = Auth::user();
                if ($user) {
                    $used_card = GiftCardUsed::where('user_id', $user->id)->first();
                    if (!$used_card) {
                        if ($is_expired == 0) {
                            if ($is_deleted == 0) {
                                if ($today->greaterThanOrEqualTo($issue_date) && $today->lessThanOrEqualTo($expiry_date)) {
                                    $discount = $giftcard->discount;
                                    $couponRemaining = 0;
                                    $amountPaidByCoupon = 0;
                                    $totalAmount = $request->session()->get('totalAmount');
                                    $discountedAmount = $totalAmount - $discount;
                                    if ($discountedAmount < 0) {
                                        $discountedAmount = 0;
                                        $amountPaidByCoupon = $totalAmount;
                                        $couponRemaining = $discount - $totalAmount;
                                    } else {
                                        $couponRemaining = 0;
                                        $amountPaidByCoupon = $totalAmount - $discountedAmount;
                                    }

                                    $couponArray = ['old_totalAmount' => $totalAmount, 'couponRemaining' => $couponRemaining, 'cardId' => $giftcard->id, 'card_amount' => $giftcard->discount, 'amountPaidByCoupon' => $amountPaidByCoupon];
                                    session(['totalAmount' => $discountedAmount]);
                                    session(['coupon_array' => $couponArray]);


                                    return response(['status' => true, 'code' => 200, 'message' => 'Valid Coupon', 'data' => $discount, 'grandTotal' => $discountedAmount, 'couponRemaining' => $couponRemaining]);
                                } elseif ($today->lessThan($issue_date)) {
                                    return response(['status' => false, 'code' => 302, 'message' => 'This coupon is no yet available.', 'start_date' => $issue_date]);
                                } else {
                                    return response(['status' => false, 'code' => 302, 'message' => 'This coupon is no longer available.']);
                                }
                            } else {
                                return response(['status' => false, 'code' => 302, 'message' => 'This coupon is no longer available.']);
                            }
                        } else {
                            return response(['status' => false, 'code' => 302, 'message' => 'This Coupon is expired.']);
                        }
                    } else {
                        return response(['status' => false, 'code' => 302, 'message' => 'This Coupon is expired.']);
                    }
                } else {
                    return response(['status' => false, 'code' => 302, 'message' => 'You have to login first to use this coupon.']);
                }
            } else {
                if ($is_expired == 0) {
                    if ($is_deleted == 0) {
                        if ($today->greaterThanOrEqualTo($issue_date) && $today->lessThanOrEqualTo($expiry_date)) {
                            $discount = $giftcard->discount;
                            $couponRemaining = 0;
                            $amountPaidByCoupon = 0;
                            $totalAmount = $request->session()->get('totalAmount');
                            $discountedAmount = $totalAmount - $discount;
                            if ($discountedAmount < 0) {
                                $discountedAmount = 0;
                                $amountPaidByCoupon = $totalAmount;
                                $couponRemaining = $discount - $totalAmount;
                            } else {
                                $couponRemaining = 0;
                                $amountPaidByCoupon = $totalAmount - $discountedAmount;
                            }

                            $couponArray = ['old_totalAmount' => $totalAmount, 'couponRemaining' => $couponRemaining, 'cardId' => $giftcard->id, 'card_amount' => $giftcard->discount, 'amountPaidByCoupon' => $amountPaidByCoupon];
                            session(['totalAmount' => $discountedAmount]);
                            session(['coupon_array' => $couponArray]);


                            return response(['status' => true, 'code' => 200, 'message' => 'Valid Coupon', 'data' => $discount, 'grandTotal' => $discountedAmount, 'couponRemaining' => $couponRemaining]);
                        } elseif ($today->lessThan($issue_date)) {
                            return response(['status' => false, 'code' => 302, 'message' => 'This coupon is no yet available.', 'start_date' => $issue_date]);
                        } else {
                            return response(['status' => false, 'code' => 302, 'message' => 'This coupon is no longer available.']);
                        }
                    } else {
                        return response(['status' => false, 'code' => 302, 'message' => 'This coupon is no longer available.']);
                    }
                } else {
                    return response(['status' => false, 'code' => 302, 'message' => 'This Coupon is expired.']);
                }
            }
        } elseif ($giftCardPurchases) {
            $expiry_date = $giftCardPurchases->expiry_date;
            $is_expired = $giftCardPurchases->is_expired;
            $is_used = $giftCardPurchases->is_used;
            $usage = $giftCardPurchases->card->usage;
            if ($giftCardPurchases->payment_method != 'Return Order') {
                if ($usage == "one_time" || $usage == "one_time_per_user") {
                    if ($is_used == 0) {
                        if ($is_expired == 0) {
                            if ($today->lessThanOrEqualTo($expiry_date)) {
                                $discount = $giftCardPurchases->total_amount;
                                $couponRemaining = 0;
                                $amountPaidByCoupon = 0;
                                $totalAmount = $request->session()->get('totalAmount');
                                $discountedAmount = $totalAmount - $discount;
                                if ($discountedAmount < 0) {
                                    $discountedAmount = 0;
                                    $amountPaidByCoupon = $totalAmount;
                                    $couponRemaining = $discount - $totalAmount;
                                } else {
                                    $couponRemaining = 0;
                                    $amountPaidByCoupon = $totalAmount - $discountedAmount;
                                }

                                $couponArray = ['old_totalAmount' => $totalAmount, 'couponRemaining' => $couponRemaining, 'cardId' => $giftCardPurchases->id, 'card_amount' => $giftCardPurchases->total_amount, 'amountPaidByCoupon' => $amountPaidByCoupon];
                                session(['totalAmount' => $discountedAmount]);
                                session(['coupon_array' => $couponArray]);

                                return response(['status' => true, 'code' => 200, 'message' => 'Valid Coupon', 'data' => $discount, 'grandTotal' => $discountedAmount, 'couponRemaining' => $couponRemaining]);
                            } else {
                                return response(['status' => false, 'code' => 302, 'message' => 'This Coupon is expired.']);
                            }
                        } else {
                            return response(['status' => false, 'code' => 302, 'message' => 'This Coupon is expired.']);
                        }
                    } else {
                        return response(['status' => false, 'code' => 302, 'message' => 'You have already used this coupon code.']);
                    }
                } else {
                    if ($today->lessThanOrEqualTo($expiry_date)) {
                        $discount = $giftCardPurchases->remaining_amount;
                        if ($discount != 0) {
                            $couponRemaining = 0;
                            $amountPaidByCoupon = 0;
                            $totalAmount = $request->session()->get('totalAmount');
                            $discountedAmount = $totalAmount - $discount;
                            if ($discountedAmount < 0) {
                                $discountedAmount = 0;
                                $amountPaidByCoupon = $totalAmount;
                                $couponRemaining = $discount - $totalAmount;
                            } else {
                                $couponRemaining = 0;
                                $amountPaidByCoupon = $totalAmount - $discountedAmount;
                            }

                            $couponArray = ['old_totalAmount' => $totalAmount, 'couponRemaining' => $couponRemaining, 'cardId' => $giftCardPurchases->id, 'card_amount' => $giftCardPurchases->remaining_amount, 'amountPaidByCoupon' => $amountPaidByCoupon];

                            session(['totalAmount' => $discountedAmount]);
                            session(['coupon_array' => $couponArray]);
                            return response(['status' => true, 'code' => 200, 'message' => 'Valid Coupon', 'data' => $discount, 'grandTotal' => $discountedAmount, 'couponRemaining' => $couponRemaining]);
                        } else {
                            return response(['status' => false, 'code' => 302, 'message' => 'This Coupon is out of balance.']);
                        }
                    } else {
                        return response(['status' => false, 'code' => 302, 'message' => 'This Coupon is expired.']);
                    }
                }
            } else {
                $discount = $giftCardPurchases->remaining_amount;
                if ($discount != 0) {
                    $couponRemaining = 0;
                    $amountPaidByCoupon = 0;
                    $totalAmount = $request->session()->get('totalAmount');
                    $discountedAmount = $totalAmount - $discount;
                    if ($discountedAmount < 0) {
                        $discountedAmount = 0;
                        $amountPaidByCoupon = $totalAmount;
                        $couponRemaining = $discount - $totalAmount;
                    } else {
                        $couponRemaining = 0;
                        $amountPaidByCoupon = $totalAmount - $discountedAmount;
                    }

                    $couponArray = ['old_totalAmount' => $totalAmount, 'couponRemaining' => $couponRemaining, 'cardId' => $giftCardPurchases->id, 'card_amount' => $giftCardPurchases->remaining_amount, 'amountPaidByCoupon' => $amountPaidByCoupon];

                    session(['totalAmount' => $discountedAmount]);
                    session(['coupon_array' => $couponArray]);
                    return response(['status' => true, 'code' => 200, 'message' => 'Valid Coupon', 'data' => $discount, 'grandTotal' => $discountedAmount, 'couponRemaining' => $couponRemaining]);
                } else {
                    return response(['status' => false, 'code' => 302, 'message' => 'This Coupon is out of balance.']);
                }
            }
        } else {
            return response(['status' => false, 'code' => 302, 'message' => 'Invalid Coupon Code.']);
        }
    }

    public function restore_grand_total()
    {
        $couponArray = session()->get('coupon_array');
        if ($couponArray) {
            $totalAmount = $couponArray['old_totalAmount'];

            session(['totalAmount' => $totalAmount]);
            Session::forget('coupon_array');
            return response(['status' => true, 'message' => 'session removed successfully']);
        }
    }
}
