<?php

namespace App\Http\Controllers\Website;

use App\General\PostClass;
use App\General\ProductClass;
use App\General\ProjectClass;
use App\General\BrandClass;
use App\General\CollectionClass;
use App\Http\Controllers\Controller;
use App\Models\Brand;
use App\Models\Category;
use App\Models\CategorySlider;
use App\Models\ChildCategory;
use App\Models\Collection;
use App\Models\GrandChildCategory;
use App\Models\order;
use App\Models\Post;
use App\Models\Product;
use App\Models\ProductMeta;
use App\Models\CollectionProduct;
use App\Models\Project;
use App\Models\Discount;
use App\Models\DynamicPage;
use App\Models\GiftCard;
use App\Models\Slider;
use App\Models\User;
use App\Models\UserAddress;
use App\Models\GeneralSettings;
use App\General\GeneralSettingsClass;
use App\Models\Invoices;
use DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\URL;
use App\Http\Controllers\Admin\Traits\InvoiceTrait;
use App\Models\ReturnOrder;

class PagesController extends Controller
{
    use InvoiceTrait;
    public $website_title = 'ToolTrade';
    public function home()
    {
        $meta_details = [
            'title' => 'Home | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrade',
        ];
        $activeStatuses = [0, 1, 2];
        $brandsliders = Slider::where('active', 1)->with('brand')->get();
        $categorysliders = CategorySlider::where('active', 1)->with('category')->orderBy('slide_number', 'asc')->get();
        $brands = Brand::where('active', 1)->get();
        $products = Product::where('active', 1)->with('discount')->orderBy('created_at', 'desc')->take(30)->get();
        $collectionproducts = Collection::with(['products.metas', 'products.discount'])->where('active', 1)->orderBy('created_at', 'desc')->take(30)
            ->get();
        $featuredproducts = Product::where('active', 1)
            ->whereHas('productMeta', function ($query) {
                $query->where('option', '_virtual')
                    ->where('value', 1);
            })
            ->with(['productMeta' => function ($query) {
                $query->whereIn('option', ['_price', '_gst', '_stock']);
            }])->with('discount')
            ->orderBy('created_at', 'desc')
            ->take(15)
            ->get();

        return view('Website.GeneralPages.home', compact('meta_details', 'brandsliders', 'categorysliders', 'brands', 'products', 'featuredproducts', 'collectionproducts'));
    }

    public function filter_products(Request $request)
    {
        $meta_details = [
            'title' => 'Search | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrade',
        ];
        $perPage = 30;
        $searchTerm = $request->input('search');
        $categoryId = $request->input('select_category') ?? 0;
        $products = Product::where('active', 1)
            ->where(function ($query) use ($searchTerm, $categoryId) {
                if ($searchTerm && $categoryId) {
                    $query->where('title', 'LIKE', '%' . $searchTerm . '%')
                        ->where('category_id', $categoryId);
                } else {
                    if ($searchTerm) {
                        $query->where('title', 'LIKE', '%' . $searchTerm . '%');
                    }
                    if ($categoryId) {
                        $query->where('category_id', $categoryId);
                    }
                }
            })
            ->paginate($perPage);
        if ($products->isNotEmpty()) {
            $category = 0;
            if (isset($products) && !empty($products)) {
                $category = Category::where('id', $products[0]->category_id ?? 0)->first();
            }
            return view('Website.GeneralPages.filtered-products', compact('meta_details', 'perPage', 'products', 'category'));
        } else {
            $meta_details = [
                'title' => 'Not Found! | ToolTrade',
                'keywords' => 'tools, genuine, hardware, makita, australia',
                'description' => 'Wholesale Hardware selling website.',
                'author' => 'ToolTrade Org',
            ];

            return view('Website.GeneralPages.NotFoundPage.product', compact('meta_details'));
        }
    }

    public function all_categories()
    {
        $meta_details = [
            'title' => 'Tools Collection | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrade',
        ];
        $perPage = 30;
        $categories = Category::paginate($perPage);
        $paginationLinks = $categories->onEachSide(1)->links('pagination::bootstrap-4');
        return view('Website.GeneralPages.all-categories', compact('meta_details', 'perPage', 'paginationLinks', 'categories'));
    }

    public function brand_details($brand)
    {
        $perPage = 30;
        $brand = Brand::where('permalink', $brand)->first();
        $products = Product::where('brand_id', $brand->id)->with('discount', 'productMeta')->paginate($perPage);
        $paginationLinks = $products->onEachSide(1)->links('pagination::bootstrap-4');

        if ($brand) {
            $brand_Title = $brand->title;
            if (!empty($seo_title = BrandClass::getOptionValue('_seo_title', $brand->BrandMeta))) {
                $product_Title = $seo_title;
            }


            $meta_details = [
                'title' => $brand_Title . ' | ' . $this->website_title,
                'keywords' => BrandClass::getOptionValue('_seo_tags', $brand->BrandMeta),
                'description' => BrandClass::getOptionValue('_seo_description', $brand->BrandMeta),
                'author' => 'ToolTrade Org',
            ];
            return view('Website.GeneralPages.brand-view', compact('meta_details', 'products', 'brand', 'paginationLinks', 'perPage'));
        } else {
            $meta_details = [
                'title' => 'Product Not Found! | ToolTrade',
                'keywords' => 'tools, genuine, hardware, makita, australia',
                'description' => 'Wholesale Hardware selling website.',
                'author' => 'ToolTrade Org',
            ];

            return view('Website.GeneralPages.brand-view', compact('meta_details'));
        }
    }
    public function cart()
    {
        $meta_details = [
            'title' => 'Cart | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrade',
        ];
        return view('Website.GeneralPages.cart', compact('meta_details'));
    }
    public function checkout()
    {
        $meta_details = [
            'title' => 'Checkout | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrade',
        ];
        return view('Website.GeneralPages.checkout', compact('meta_details'));
    }
    public function shop()
    {
        $meta_details = [
            'title' => 'Shop | ToolTrade',
            'keywords' => 'donate, donation, charity, ToolTrade, organization',
            'description' => 'Support our cause by making a donation to ToolTrade. Together, we can make a difference in the lives of those in need.',
            'author' => 'ToolTrade Org',
        ];
        $products = Product::where('active', 1)->get();
        return view('Website.GeneralPages.shop', compact('meta_details', 'products'));
    }
    public function product($permalink)
    {
        $product = Product::where('permalink', $permalink)->first();

        if ($product) {
            $product_Title = $product->product_title;
            if (!empty($seo_title = ProductClass::getOptionValue('_seo_title', $product->productMeta))) {
                $product_Title = $seo_title;
            }
            $meta_details = [
                'title' => $product_Title . ' | ' . $this->website_title,
                'keywords' => ProductClass::getOptionValue('_seo_tags', $product->productMeta),
                'description' => ProductClass::getOptionValue('_seo_description', $product->productMeta),
                'author' => 'ToolTrade Org',
            ];
            return view('Website.GeneralPages.product', compact('product', 'meta_details'));
        } else {
            $meta_details = [
                'title' => 'Product Not Found! | ToolTrade',
                'keywords' => 'donate, donation, charity, ToolTrade, organization',
                'description' => 'Support our cause by making a donation to ToolTrade. Together, we can make a difference in the lives of those in need.',
                'author' => 'ToolTrade Org',
            ];
            return view('Website.GeneralPages.NotFoundPage.product', compact('meta_details'));
        }
    }

    public function profile()
    {
        $user = User::where('id', Auth::id())->with('userMeta')->first();
        $shipping = UserAddress::where('id', 1)->with('user')->first();
        $addresses = UserAddress::where('user_id', Auth::id())->get();
        $orders = order::where('user_id', $user->id)->orWhere('email', $user->email)->where('status', '!=', 'refund')
            ->with('orderMetas.product')->orderBy('id', 'desc')
            ->paginate(10);
        $returns = ReturnOrder::where('user_id', $user->id)->orWhere('User_email', $user->email)->orderBy('id', 'desc')->with('returnMeta', 'order')
            ->paginate(10);
        $invoices = Invoices::where('is_deleted', 0)->where('customer', Auth::id())->where('active', 1)->orderBy('id', 'DESC')->paginate(10);
        $meta_details = [
            'title' => 'Profile | ToolTrade',
            'keywords' => 'donate, donation, charity, ToolTrade, organization',
            'description' => 'Support our cause by making a donation to ToolTrade. Together, we can make a difference in the lives of those in need.',
            'author' => 'ToolTrade Org',
        ];
        return view('Website.GeneralPages.profile', compact('meta_details', 'user', 'shipping', 'addresses', 'orders', 'invoices', 'returns'));
    }
    public function generatePdf_pos($id)
    {
        $Invoice_review = $this->ReviewInvoice($id);
        return response()->json(['message' => 'Invoice updated successfully', 'invoice_review' => $Invoice_review], 200);
    }
    public function login()
    {
        $meta_details = [
            'title' => 'SignIn | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrade',
        ];
        return view('Website.GeneralPages.login', compact('meta_details'));
    }
    public function register()
    {
        $meta_details = [
            'title' => 'SignUp | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrade',
        ];
        $categories = Category::get();
        return view('Website.GeneralPages.register', compact('meta_details', 'categories'));
    }
    public function forgetPassword()
    {
        $meta_details = [
            'title' => 'Forget Password | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrade',
        ];
        return view('Website.GeneralPages.forgetPassword', compact('meta_details'));
    }
    public function reset_password(Request $request)
    {
        $token = $request->query('token');
        $meta_details = [
            'title' => 'Reset Password | ToolTrade',
            'keywords' => 'ToolTrade, organization',
            'description' => 'Support our cause by making a donation to ToolTrade.',
            'author' => 'ToolTrade Org',
        ];
        return view('Website.GeneralPages.reset_password', compact('meta_details', 'token'));
    }

    public function project($permalink)
    {
        $project = Project::where('permalink', $permalink)->first();
        if ($project) {
            $project_Title = $project->project_title . ' | ToolTrade';
            if (!empty($seo_title = ProjectClass::getOptionValue('_seo_title', $project->projectMeta))) {
                $project_Title = $seo_title;
            }
            $meta_details = [
                'title' => $project_Title,
                'keywords' => ProjectClass::getOptionValue('_seo_tags', $project->projectMeta),
                'description' => ProjectClass::getOptionValue('_seo_description', $project->projectMeta),
                'author' => 'ToolTrade Org',
            ];
            return view('Website.GeneralPages.project', compact('project', 'meta_details'));
        } else {
            $meta_details = [
                'title' => 'Project Not Found! | ToolTrade',
                'keywords' => 'ToolTrade, organization',
                'description' => 'Support our cause by making a donation to ToolTrade.',
                'author' => 'ToolTrade Org',
            ];
            return view('Website.GeneralPages.NotFoundPage.project', compact('meta_details'));
        }
    }
    public function volunteer()
    {
        $meta_details = [
            'title' => 'Volunteer | ToolTrade',
            'keywords' => 'ToolTrade, organization',
            'description' => 'Support our cause by making a donation to ToolTrade.',
            'author' => 'ToolTrade Org',
        ];
        return view('Website.GeneralPages.volunteer', compact('meta_details'));
    }

    public function posts()
    {
        $meta_details = [
            'title' => 'Blog - Posts | ToolTrade',
            'keywords' => 'ToolTrade, organization',
            'description' => 'Support our cause by making a donation to ToolTrade.',
            'author' => 'ToolTrade Org',
        ];

        $posts = Post::where('active', 1)->get();
        return view('Website.GeneralPages.Posts', compact('meta_details', 'posts'));
    }

    public function thankyouPage()
    {
        $meta_details = [
            'title' => 'Thanks, Order Placed | ToolTrade',
            'keywords' => 'donate, donation, charity, ToolTrade, organization',
            'description' => 'Support our cause by making a donation to ToolTrade.',
            'author' => 'ToolTrade Org',
        ];
        $settings = GeneralSettings::get();
        $store_invoice_note = GeneralSettingsClass::getOptionValue('_store_order_note', $settings);
        return view('Website.GeneralPages.thankyou', compact('meta_details', 'store_invoice_note'));
    }

    public function post($permalink)
    {
        $post = Post::where('permalink', $permalink)->first();

        if ($post) {
            $post_Title = $post->post_title . ' | ToolTrade';
            if (!empty($seo_title = PostClass::getOptionValue('_seo_title', $post->postMeta))) {
                $post_Title = $seo_title;
            }
            $meta_details = [
                'title' => $post_Title,
                'keywords' => PostClass::getOptionValue('_seo_tags', $post->postMeta),
                'description' => PostClass::getOptionValue('_seo_description', $post->postMeta),
                'author' => 'ToolTrade Org',
            ];
            return view('Website.GeneralPages.post', compact('post', 'meta_details'));
        } else {
            $meta_details = [
                'title' => 'Post Not Found! | ToolTrade',
                'keywords' => 'donate, donation, charity, ToolTrade, organization',
                'description' => 'Support our cause by making a donation to ToolTrade.',
                'author' => 'ToolTrade Org',
            ];
            return view('Website.GeneralPages.NotFoundPage.post', compact('meta_details'));
        }
    }

    public function checkPostcode(Request $request)
    {
        $postCode = $request->input('post_code');
        $productId = $request->input('product_id');

        $product = Product::find($productId);

        if ($product->area_group_id == "0") {
            return response()->json(['area_group_exit' => true]);
        }

        if ($product && $product->area_group_id) {
            $areaGroupIds = explode(',', $product->area_group_id);

            if (in_array($postCode, $areaGroupIds)) {
                return response()->json(['area_group_exit' => true]);
            }
        }

        return response()->json(['area_group_exit' => false]);
    }

    public function updateCart(Request $request)
    {
        // Get the percentage value from the environment configuration
        // $percentage = env('PERCENTAGE', 0);
        $percentage = config('app.PERCENTAGE');
        $updatedCartData = session('cartData', []);
        $pId = $request->input('pId');
        $title = $request->input('title');
        $amount = $request->input('amount');
        $featuredImage = $request->input('featuredImage');
        $gst = $request->input('gst');
        $pIdToRemove = $request->input('pIdToRemove');
        $quantity = $request->input('quantity');
        $productGst = $request->input('productGst');
        $increaseQuantity = $request->input('increaseQuantity');
        $decreaseQuantity = $request->input('decreaseQuantity');

        $productStock = ProductMeta::where('product_id', $pId == null ? $pIdToRemove : $pId)
            ->where('option', '_stock')
            ->first();
        $productPrice = ProductMeta::where('product_id', $pId == null ? $pIdToRemove : $pId)
            ->where('option', '_price')
            ->first();
        if ($productStock->value >= $quantity) {
            $totalGst = 0;
            $subTotal = 0;
            if ($pIdToRemove !== null) {
                $updatedCartData = array_values(array_filter($updatedCartData, function ($product) use ($pIdToRemove) {
                    return $product['pId'] !== $pIdToRemove;
                }));
            }
            $existingProductIndex = -1;
            if (isset($updatedCartData) && !empty($updatedCartData)) {
                foreach ($updatedCartData as $index => $product) {
                    if ($product['pId'] === $pId) {
                        $existingProductIndex = $index;
                        break;
                    }
                }
            }
            if ($existingProductIndex !== -1) {
                if ($productStock->value > $updatedCartData[$existingProductIndex]['quantity']) {
                    if ($increaseQuantity !== null) {
                        $updatedCartData[$existingProductIndex]['quantity'] = intval($increaseQuantity);
                    } elseif ($decreaseQuantity !== null) {
                        $updatedCartData[$existingProductIndex]['quantity'] = intval($decreaseQuantity);
                    } else {
                        $updatedCartData[$existingProductIndex]['quantity'] += intval($quantity);
                    }
                } else {
                    return response()->json(['message' => 'Sorry We do not have more quantity of this product', 'status' => false]);
                }
            } else {
                $cartData = [
                    'pId' => $pId,
                    'title' => $title,
                    'amount' => $amount,
                    'featuredImage' => $featuredImage,
                    'quantity' => $quantity,
                    'productGst' => $productGst,
                ];
                if ($gst == 1) {
                    $cartData['gst'] = $gst;
                    if ($cartData['productGst'] == 0) {
                        $productGst = (intval($amount) * intval($percentage) / 100);
                        $cartData['productGst'] = intval($productGst);
                    }
                } else {
                    $cartData['productGst'] = 0;
                }
                if ($cartData['pId'] !== null && $cartData['title'] !== null) {
                    $updatedCartData[] = $cartData;
                }
            }
            session(['cartData' => $updatedCartData]);

            $amounts = [];
            $totalAmount = 0;
            $totalGst = 0;
            $totalProducts = count($updatedCartData);

            foreach ($updatedCartData as $product) {
                $amount = $product['amount'];
                $gst = isset($product['gst']) ? $product['gst'] : null;

                if ($gst == 1) {
                    $amount += (intval($amount) * intval($percentage) / 100);
                }
                $totalGst += intval($product['productGst']) * intval($product['quantity']);
                $subTotal += intval($amount) * intval($product['quantity']);
            }
            $totalAmount = $subTotal;
            $amounts = ['totalAmount' => $totalAmount, 'subTotal' => $subTotal, 'gst' => $totalGst];

            session(['totalAmount' => $totalAmount]);
            session(['totalProducts' => $totalProducts]);
            session(['totalGst' => $totalGst]);
            session(['subTotal' => $subTotal]);

            return response()->json(['message' => 'Session data updated.', 'data' => $updatedCartData, 'amounts' => $amounts, 'status' => true]);
        } else {
            return response()->json(['message' => 'Sorry We do not have your required quantity of this product.', 'status' => false]);
        }
    }

    public function getCartItemNumbers()
    {
        $cartData = session('cartData', []);
        $total_items = count($cartData);
        session(['total_items' => $total_items]);
        return response()->json($total_items);
    }

    public function showCartdata()
    {
        $cartData = session('cartData', []);
        $totalAmount = session('totalAmount', 0);
        $subTotal = 0;

        if (!empty($cartData)) {
            foreach ($cartData as $product) {
                $amount = $product['amount'];
                $quantity = $product['quantity'];
                $subtotal = intval($amount) * intval($quantity);
                $subTotal += intval($subtotal);
            }
        }
        $totalIncludingGST = $totalAmount;
        $percentage = config('app.PERCENTAGE');

        return view('Website.GeneralPages.ajax.cart', compact('cartData', 'subTotal', 'totalIncludingGST'))->render();
    }


    public function single_product(Request $request, $permalink)
    {
        $categories = Category::all();
        $childcats = ChildCategory::all();
        $grandcats = GrandChildCategory::all();
        $product = Product::where('permalink', $permalink)->where('active', 1)->with('type')->firstOrFail();

        $categoryproducts = Product::with(['category', 'productMeta' => function ($query) {
            $query->whereIn('option', ['_price', '_gst', '_stock']);
        }])
            ->where('active', 1)
            ->where('category_id', $product->category_id)
            ->get();

        $brandlogo = DB::table('brands')->where('id', $product->brand_id)->select('logo_image', 'title')->first();

        $disocuntonproduct = DB::table('discounts')->where('id', $product->discount_id)->select('title', 'active', 'badge_text', 'badge_color', 'badge_image', 'discount_value', 'limited', 'from_date', 'end_date', 'discount_type')->first();
        $currentDate = time();
        $fromDate = strtotime($disocuntonproduct->from_date ?? 0);
        $toDate = strtotime($disocuntonproduct->end_date ?? 0);
        if ($currentDate <= $fromDate || $currentDate >= $toDate) {
            $disocuntonproduct = null;
        }

        $collectionDiscount = null;

        if (!$disocuntonproduct) {
            $collectionproducts = CollectionProduct::where('product_id', $product->id)->with('collection')->first();
            $collectionDiscount = Discount::where('id', $collectionproducts->collection->discount_id ?? 0)->first();
        }

        $featuredproducts = Product::where('active', 1)
            ->whereHas('productMeta', function ($query) {
                $query->where('option', '_virtual')
                    ->where('value', 1);
            })
            ->with(['productMeta' => function ($query) {
                $query->whereIn('option', ['_price', '_gst', '_stock']);
            }])
            ->orderBy('created_at', 'desc')
            ->take(15)
            ->get();

        if ($product) {
            $product_Title = $product->title;
            if (!empty($seo_title = ProductClass::getOptionValue('_seo_title', $product->productMeta))) {
                $product_Title = $seo_title;
            }
            $meta_details = [
                'title' => $product_Title . ' | ' . $this->website_title,
                'keywords' => ProductClass::getOptionValue('_seo_tags', $product->productMeta),
                'description' => ProductClass::getOptionValue('_seo_description', $product->productMeta),
                'author' => 'ToolTrade Org',
            ];
            return view('Website.GeneralPages.product', compact('meta_details', 'product', 'categories', 'childcats', 'grandcats', 'featuredproducts', 'categoryproducts', 'brandlogo', 'disocuntonproduct', 'collectionDiscount'));
        } else {
            $meta_details = [
                'title' => 'Product Not Found! | ToolTrade',
                'keywords' => 'tools, genuine, hardware, makita, australia',
                'description' => 'Wholesale Hardware selling website.',
                'author' => 'ToolTrade Org',
            ];
        }
    }

    public function kit_product()
    {
        $meta_details = [
            'title' => 'Kit Product | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrad',
        ];
        return view('Website.GeneralPages.kit', compact('meta_details'));
    }

    public function all_featured_products()
    {
        $meta_details = [
            'title' => 'Featured Products | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrad',
        ];
        $perPage = 30;
        $featuredproducts = Product::where('active', 1)
            ->whereHas('productMeta', function ($query) {
                $query->where('option', '_virtual')
                    ->where('value', 1);
            })
            ->with(['productMeta' => function ($query) {
                $query->whereIn('option', ['_price', '_gst', '_stock']); // Load _gst and _price productMeta
            }])->with('discount')
            ->orderBy('created_at', 'desc')
            ->paginate($perPage);
        $paginationLinks = $featuredproducts->onEachSide(1)->links('pagination::bootstrap-4');

        return view('Website.GeneralPages.product-featured-view', compact('meta_details', 'featuredproducts', 'paginationLinks', 'perPage'));
    }

    public function all_products()
    {
        $meta_details = [
            'title' => 'All Products | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrad',
        ];
        $perPage = 30;
        $featuredproducts = Product::where('active', 1)->with('productMeta')->paginate($perPage);
        $paginationLinks = $featuredproducts->onEachSide(1)->links('pagination::bootstrap-4');
        return view('Website.GeneralPages.all-product-view', compact('meta_details', 'featuredproducts', 'paginationLinks', 'perPage'));
    }

    public function brands()
    {
        $meta_details = [
            'title' => 'Brands | ' . $this->website_title,
            'keywords' => 'tools, genuine, harware, makita, australia',
            'description' => 'Whole sale Hardware selling website',
            'author' => 'ToolTrad',
        ];
        $activeStatuses = [0, 1, 2];
        $brands = Brand::whereIn('active', $activeStatuses)->get();
        return view('Website.GeneralPages.brands', compact('meta_details', 'brands'));
    }

    public function category_product($category_sku)
    {
        $category = Category::where('sku', $category_sku)->first();

        if ($category) {
            $perPage = 30;
            $products = Product::where('category_id', $category->id)->with('discount', 'productMeta')->paginate($perPage);
            $paginationLinks = $products->onEachSide(1)->links('pagination::bootstrap-4');
            $meta_details = [
                'title' =>  $category->title . ' | ' . $this->website_title,
                'keywords' => 'tools, genuine, hardware, makita, australia',
                'description' => 'Wholesale Hardware selling website for ' . $category->title,
                'author' => 'ToolTrad',
            ];

            return view('Website.GeneralPages.category-view', compact('products', 'paginationLinks', 'perPage', 'meta_details', 'category'));
        } else {
            $meta_details = [
                'title' => 'Not Found! | ToolTrade',
                'keywords' => 'tools, genuine, hardware, makita, australia',
                'description' => 'Wholesale Hardware selling website.',
                'author' => 'ToolTrade Org',
            ];
            $heading_word = 'Category';

            return view('Website.GeneralPages.NotFoundPage.category', compact('meta_details', 'heading_word'));
        }
    }

    public function childcategory_product($childcategory_sku)
    {
        $childcategory = ChildCategory::where('child_sku', $childcategory_sku)->first();
        if ($childcategory) {
            $perPage = 30;
            $products = Product::where('child_category', $childcategory->id)->with('discount')->paginate($perPage);
            $paginationLinks = $products->onEachSide(1)->links('pagination::bootstrap-4');
            $meta_details = [
                'title' => $childcategory->child_title . ' | ' . $this->website_title,
                'keywords' => 'tools, genuine, hardware, makita, australia',
                'description' => 'Wholesale Hardware selling website for ' . $childcategory->child_title,
                'author' => 'ToolTrad',
            ];

            return view('Website.GeneralPages.childcategory-view', compact('products', 'paginationLinks', 'perPage', 'meta_details', 'childcategory'));
        } else {
            $meta_details = [
                'title' => 'Not Found! | ToolTrade',
                'keywords' => 'tools, genuine, hardware, makita, australia',
                'description' => 'Wholesale Hardware selling website.',
                'author' => 'ToolTrade Org',
            ];
            $heading_word = 'Child Category';

            return view('Website.GeneralPages.NotFoundPage.category', compact('meta_details', 'heading_word'));
        }
    }

    public function grand_childcategory_product($grandchildcategory_sku)
    {
        $grandchildcategory = GrandChildCategory::where('grand_sku', $grandchildcategory_sku)->first();
        if ($grandchildcategory) {
            $perPage = 30;
            $products = Product::where('grand_child_category', $grandchildcategory->id)->with('discount')->paginate($perPage);
            $paginationLinks = $products->onEachSide(1)->links('pagination::bootstrap-4');
            $meta_details = [
                'title' => $grandchildcategory->grand_title . ' | ' . $this->website_title,
                'keywords' => 'tools, genuine, hardware, makita, australia',
                'description' => 'Wholesale Hardware selling website for ' . $grandchildcategory->grand_title,
                'author' => 'ToolTrad',
            ];
            return view('Website.GeneralPages.grand-childcategory-view', compact('products', 'paginationLinks', 'perPage', 'meta_details', 'grandchildcategory'));
        } else {
            $meta_details = [
                'title' => 'Not Found! | ToolTrade',
                'keywords' => 'tools, genuine, hardware, makita, australia',
                'description' => 'Wholesale Hardware selling website.',
                'author' => 'ToolTrade Org',
            ];
            $heading_word = 'Grand Child Category';

            return view('Website.GeneralPages.NotFoundPage.category', compact('meta_details', 'heading_word'));
        }
    }

    public function dynamic_page($permalink)
    {
        $page = DynamicPage::where('permalink', $permalink)->first();
        if ($page) {
            $meta_details = [
                'title' => $page->title ?? "Page",
                'keywords' => $page->seo_tags ?? "Tags",
                'description' => $page->seo_description ?? "Description",
                'author' => 'ToolTrade',
            ];
            return view('Website.GeneralPages.dynamic-content-page', compact('page', 'meta_details'));
        } else {
            $meta_details = [
                'title' => $page->title ?? "Page",
                'keywords' => $page->seo_tags ?? "Tags",
                'description' => $page->seo_description ?? "Description",
                'author' => 'ToolTrade',
            ];
            return view('Website.GeneralPages.NotFoundPage.page', compact('page', 'meta_details'));
        }
    }
    
    public function gift_cards()
    {
        $giftCards = GiftCard::where('variant', 'gift_card')->where('status', 'active')->get();
        if ($giftCards->isNotEmpty()) {
            $meta_details = [
                'title' => 'Gift Cards | ' . $this->website_title,
                'keywords' => 'tools, genuine, harware, makita, australia',
                'description' => 'Gift Cards can be a very usefull thing to gift someone.',
                'author' => 'ToolTrade',
            ];
            return view('Website.GeneralPages.gift-cards', compact('meta_details', 'giftCards'));
        } else {
            $meta_details = [
                'title' => 'Not Found | ' . $this->website_title,
                'keywords' => 'tools, genuine, harware, makita, australia',
                'description' => 'Gift Cards can be a very usefull thing to gift someone.',
                'author' => 'ToolTrade',
            ];
            return view('Website.GeneralPages.NotFoundPage.gift-card', compact('meta_details'));
        }
    }
    public function gift_card_checkout_page($id)
    {
        $gift_card = GiftCard::where('id', base64_decode($id))->first();
        if ($gift_card->status == 'active') {
            $meta_details = [
                'title' => 'Gift Cards Checkout | ' . $this->website_title,
                'keywords' => 'tools, genuine, harware, makita, australia',
                'description' => 'Gift Cards can be a very usefull thing to gift someone.',
                'author' => 'ToolTrade',
            ];
            return view('Website.GeneralPages.gift-cards-checkout', compact('meta_details', 'gift_card'));
        }
    }

    public function getCollectionProducts(Request $request)
    {
        $selectedCollectionId = $request->input('collection_id');
        $collectionproducts = Collection::with(['products.metas', 'products.discount'])
            ->where('id', $selectedCollectionId)
            ->where('active', 1)
            ->orderBy('created_at', 'desc')
            ->take(30)
            ->get();

        $html = '';

        if (isset($collectionproducts) && !empty($collectionproducts)) {
            foreach ($collectionproducts as $collectionproduct) {
                if ($collectionproduct->products->isNotEmpty()) {
                    foreach ($collectionproduct->products as $c_product) {
                        $discountedPrice = 0;
                        $fromDate = 0;
                        $currentDate = 0;
                        $toDate = 0;
                        if (isset($c_product) && $c_product->discount !== null) {
                            if ($c_product->active == 1) {
                                $currentDate = time();
                                $fromDate = strtotime($c_product->discount->from_date);
                                $toDate = strtotime($c_product->discount->end_date);
                                $discountedPrice = 0;
                                if ($c_product->discount->limited == 0) {
                                    $discountValue = $c_product->discount->discount_value;
                                    $actualPrice = ProductClass::getOptionValue('_price', $c_product->metas);
                                    $discountAmount = ($discountValue / 100) * $actualPrice;
                                    $discountedPrice = $actualPrice - $discountAmount;
                                } elseif ($c_product->discount->limited == 1) {
                                    if ($currentDate >= $fromDate && $currentDate <= $toDate) {
                                        $fromDate = strtotime($c_product->discount->from_date);
                                        $toDate = strtotime($c_product->discount->end_date);
                                        $discountValue = $c_product->discount->discount_value;
                                        $actualPrice = ProductClass::getOptionValue('_price', $c_product->metas);
                                        $discountAmount = ($discountValue / 100) * $actualPrice;
                                        $discountedPrice = $actualPrice - $discountAmount;
                                    } else {
                                        $discountedPrice = ProductClass::getOptionValue('_price', $c_product->metas);
                                    }
                                }
                            } else {
                                $discountedPrice = ProductClass::getOptionValue('_price', $c_product->metas);
                            }
                        }

                        if (isset($c_product)) {
                            $html .= '<div class="col-lg-2 col-md-4 col-sm-12 col-border-top-r">
                        <div class="product-detail-section">
                            <div class="card product-card">
                                <div class="card-body">
                                    <div class="product-back-img">
                                        <div class="image-container" style="background-image: url(\'' . url('/') . '/' . $c_product->featured_image . '\');"></div>';
                            $collection_products = DB::table('collection_products')
                                ->join('collections', 'collections.id', '=', 'collection_products.collection_id')
                                ->join('discounts', 'discounts.id', '=', 'collections.discount_id')
                                ->where('product_id', $c_product->id)
                                ->first();
                            if ($c_product->discount_id == 0) {
                                if ($collection_products) {
                                    if ($collection_products->limited == 1) {
                                        $currentDate = time();
                                        $fromDate = strtotime($collection_products->from_date);
                                        $toDate = strtotime($collection_products->end_date);
                                        if ($collection_products->active == 1) {
                                            if ($currentDate >= $fromDate && $currentDate <= $toDate) {
                                                if ($collection_products->discount_type == 1) {
                                                    $html .= '<p class="product-discount">Save ' . $collection_products->discount_value . '$ </p>';
                                                } else {
                                                    $html .= '<p class="product-discount">Save ' . $collection_products->discount_value . ' %</p>';
                                                }
                                            } else {
                                                $html .= '<p class="product-discount-dynamic">Save 0</p>';
                                            }
                                        } else {
                                            $html .= '<p class="product-discount-dynamic">Save 0</p>';
                                        }
                                    } else {
                                        if ($collection_products->active == 1) {
                                            if ($collection_products->discount_type == 1) {
                                                $html .= '<p class="product-discount">Save ' . $collection_products->discount_value . '$ </p>';
                                            } else {
                                                $html .= '<p class="product-discount">Save ' . $collection_products->discount_value . ' %</p>';
                                            }
                                        } else {
                                            $html .= '<p class="product-discount-dynamic">Save 0</p>';
                                        }
                                    }
                                } else {
                                    $html .= '<p class="product-discount-dynamic">Save 0</p>';
                                }
                            } else {
                                if ($c_product->discount != null) {
                                    $currentDate = time();
                                    $fromDate = strtotime($c_product->discount->from_date);
                                    $toDate = strtotime($c_product->discount->end_date);
                                    if ($c_product->discount->active == 1) {
                                        if ($c_product->limited == 1 && $currentDate >= $fromDate && $currentDate <= $toDate) {
                                            if ($c_product->discount->discount_type == 1) {
                                                $html .= '<p class="product-discount">Save ' . $c_product->discount->discount_value . ' $</p>';
                                            } else {
                                                $html .= '<p class="product-discount">Save ' . $c_product->discount->discount_value . '%</p>';
                                            }
                                        } else {
                                            if ($c_product->discount->discount_type == 1) {
                                                $html .= '<p class="product-discount">Save ' . $c_product->discount->discount_value . ' $</p>';
                                            } else {
                                                $html .= '<p class="product-discount">Save ' . $c_product->discount->discount_value . '%</p>';
                                            }
                                        }
                                    } else {
                                        $html .= '<p class="product-discount-dynamic">Save 0</p>';
                                    }
                                } else {
                                    $html .= '<p class="product-discount-dynamic">Save 0</p>';
                                }
                            }
                            $html .= '</div>
                                    <div class="product-details">
                                        <a class="product-detail-desc texttracate" href="' . url('/') . '/product/' . $c_product->permalink . '">' . $c_product->title . '</a>
                                        <p><span class="product-detail-amount">$';

                            $discountedPriceHtml = '';

                            if ($c_product->discount_id == 0) {
                                if ($collection_products) {
                                    if ($collection_products->active == 1) {
                                        if ($collection_products->limited == 1) {
                                            $currentDate = time();
                                            $fromDate = strtotime($collection_products->from_date);
                                            $toDate = strtotime($collection_products->end_date);
                                            if ($currentDate >= $fromDate && $currentDate <= $toDate) {
                                                if ($collection_products->discount_type == 1) {
                                                    $discountedPriceHtml .= intval(ProductClass::getOptionValue('_price', $c_product->metas) - ($collection_products->discount_value ?? 0));
                                                } else {
                                                    $discountedPriceHtml .= number_format(ProductClass::getOptionValue('_price', $c_product->metas) - (ProductClass::getOptionValue('_price', $c_product->metas) * ($collection_products->discount_value ?? 0) / 100), 2);
                                                }
                                            } else {
                                                $discountedPriceHtml .= ProductClass::getOptionValue('_price', $c_product->metas);
                                            }
                                        } else {
                                            if ($collection_products->discount_type == 1) {
                                                $discountedPriceHtml .= intval(ProductClass::getOptionValue('_price', $c_product->metas) - ($collection_products->discount_value ?? 0));
                                            } else {
                                                $discountedPriceHtml .= number_format(ProductClass::getOptionValue('_price', $c_product->metas) - (ProductClass::getOptionValue('_price', $c_product->metas) * ($collection_products->discount_value ?? 0) / 100), 2);
                                            }
                                        }
                                    } else {
                                        $discountedPriceHtml .= ProductClass::getOptionValue('_price', $c_product->metas);
                                    }
                                } else {
                                    $discountedPriceHtml .= intval(ProductClass::getOptionValue('_price', $c_product->metas) - ($collection_products->discount_value ?? 0));
                                }
                            } else {
                                if ($c_product->discount != null) {
                                    $currentDate = time();
                                    $fromDate = strtotime($c_product->discount->from_date);
                                    $toDate = strtotime($c_product->discount->end_date);
                                    if ($c_product->discount->active == 1) {
                                        if ($c_product->limited == 1 && $currentDate >= $fromDate && $currentDate <= $toDate) {
                                            if ($c_product->discount->discount_type == 1) {
                                                $discountedPriceHtml .= intval(ProductClass::getOptionValue('_price', $c_product->metas) - ($c_product->discount->discount_value ?? 0));
                                            } else {
                                                $discountedPriceHtml .= number_format(ProductClass::getOptionValue('_price', $c_product->metas) - (ProductClass::getOptionValue('_price', $c_product->metas) * ($c_product->discount->discount_value ?? 0) / 100), 2);
                                            }
                                        } else {
                                            $discountedPriceHtml .= ProductClass::getOptionValue('_price', $c_product->metas);
                                        }
                                    } else {
                                        $discountedPriceHtml .= ProductClass::getOptionValue('_price', $c_product->metas);
                                    }
                                } else {
                                    $discountedPriceHtml .= number_format(ProductClass::getOptionValue('_price', $c_product->metas) - (ProductClass::getOptionValue('_price', $c_product->metas) * ($c_product->discount->discount_value ?? 0) / 100), 2);
                                }
                            }

                            if ($discountedPriceHtml == ProductClass::getOptionValue('_price', $c_product->metas)) {
                                $html .= $discountedPriceHtml;
                            } else {
                                $html .= $discountedPriceHtml . '</span><small class="product-detail-discount"><del>$' . ProductClass::getOptionValue('_price', $c_product->metas) . '</del></small></p>';
                            }
                            $btn_disabled = '';
                            $btn_text = 'Add to Cart';
                            $product_stock = ProductClass::getOptionValue('_stock', $c_product->metas);
                            if ($product_stock == 0) {
                                $btn_disabled = 'disabled';
                                $btn_text = 'Out of Stock';
                            }
                            $html .=   '</div>
                                    <div class="product-detail-addtocart-btn">
                                        <a class="TextDecor">
                                            <button class="btn futured-product-add-tocart-btn"' . $btn_disabled . '
                                                    data-gst="' . ProductClass::getOptionValue('_gst', $c_product->metas) . '"
                                                    data-title="' . $c_product->title . '"
                                                    data-amount="' . $discountedPriceHtml . '"
                                                    data-p_id="' . $c_product->id . '"
                                                    data-featured_image="' . url('/') . '/' . $c_product->featured_image . '">
                                                ' . $btn_text . '
                                            </button>
                                        </a>
                                    </div>
                                    <div class="product-detail-tags">';
                            if ($c_product->discount_id == 0) {
                                $badgeText = $collection_products->badge_text ?? '';
                                $badgeColor = $collection_products->badge_color ?? '';
                                $imagePaths = explode(',', ($collection_products->badge_image ?? ''));

                                foreach ($imagePaths as $imagePath) {
                                    if (!empty($imagePath)) {
                                        $html .= '<img src="' . asset($imagePath) . '" class="m-1" alt="">';
                                    }
                                }

                                $textPaths = explode(',', $badgeText);
                                foreach ($textPaths as $textPath) {
                                    if (!empty($textPath) && $textPath !== "") {
                                        $html .= '<a style="border: 2px solid ' . $badgeColor . '; color: ' . $badgeColor . ';">' . $textPath . '</a>';
                                    } else {
                                        $badgeColor = isset($c_product->discount) ? $c_product->discount->badge_color : '';
                                        $html .= '';
                                    }
                                }
                            } else {
                                $badge_text = isset($collection_products) ? $collection_products->badge_text : '';
                                $textPaths = explode(',', $badge_text);
                                $image_badge = isset($c_product->discount) ? $c_product->discount->badge_image : '';
                                $imagePaths = explode(',', $image_badge);
                                foreach ($textPaths as $textPath) {
                                    if (!empty($textPaths) && $textPath !== "") {
                                        $badgeColor = isset($c_product->discount) ? $c_product->discount->badge_color : '';
                                        $html .= '<a style="border: 2px solid ' . $badgeColor . '; color: ' . $badgeColor . ';">' . implode(', ', $textPaths) . '</a>';
                                    } else {
                                        $badgeColor = isset($c_product->discount) ? $c_product->discount->badge_color : '';
                                        $html .= '';
                                    }
                                }
                                foreach ($imagePaths as $imagePath) {
                                    if (!empty($imagePath)) {
                                        $html .= '<img src="' . asset($imagePath) . '" class="m-1" alt="">';
                                    }
                                }
                            }
                            $html .= '</div>
                                </div>
                            </div>
                        </div>
                    </div>';
                        }
                    }
                } else {
                    $html .= '<div class="text-center"><p class="text-danger" style="font-size: 16px; font-weight: bold;">Sorry No Product Found in this collection.</p></div>';
                }
            }
        } else {
            $html .= '<div class="col-lg-2 col-md-4 col-sm-12 col-border-top-r">
                        <div class="product-detail-section">
                        <p><b>No product found in this collection. You can explore more collection using the dropdown above.</b></p>';
        }

        if ($request->ajax()) {
            return response()->json(['html' => $html]);
        }
    }

    public function collection_product(Request $request)
    {
        $perPage = 1;
        $collectionfirst = Collection::with(['products.metas', 'products.discount'])->orderBy('created_at', 'desc')->first();
        $collectionproducts = Collection::with(['products.metas', 'products.discount'])->where('active', 1)->where('permalink', $request->permalink)->orderBy('created_at', 'desc')->take(30)
            ->get();
        $allCollections = Collection::where('active', 1)->with(['products.metas', 'products.discount'])->get();
        $selectedCollection = Collection::where('permalink', $request->permalink)->first();

        if ($collectionproducts->isNotEmpty()) {
            $collection_Title = $collectionfirst->title;
            if (!empty($seo_title = CollectionClass::getOptionValue('_seo_title', $collectionfirst->CollectionMeta))) {
                $product_Title = $seo_title;
            }
            $meta_details = [
                'title' => $collection_Title . ' | ' . $this->website_title,
                'keywords' => CollectionClass::getOptionValue('_seo_tags', $collectionfirst->CollectionMeta),
                'description' => CollectionClass::getOptionValue('_seo_description', $collectionfirst->CollectionMeta),
                'author' => 'ToolTrade Org',
            ];
            return view('Website.GeneralPages.collection-product', compact('meta_details', 'collectionproducts', 'selectedCollection', 'allCollections'));
        } else {
            $meta_details = [
                'title' => 'Collection Not Found! | ToolTrade',
                'keywords' => 'tools, genuine, hardware, makita, australia',
                'description' => 'Wholesale Hardware selling website.',
                'author' => 'ToolTrade Org',
            ];

            return view('Website.GeneralPages.NotFoundPage.collection', compact('meta_details'));
        }
    }

    public function CollectionProducts(Request $request)
    {
        $selectedCollectionId = $request->input('collection_id');
        $collectionproducts = Collection::with(['products.metas', 'products.discount'])
            ->where('id', $selectedCollectionId)
            ->orderBy('created_at', 'desc')
            ->take(30)
            ->get();

        $html = '';

        foreach ($collectionproducts as $collectionproduct) {
            if ($collectionproduct->products->isNotEmpty()) {
                foreach ($collectionproduct->products as $c_product) {
                    $discountedPrice = 0;
                    $fromDate = 0;
                    $currentDate = 0;
                    $toDate = 0;
                    if (isset($c_product) && $c_product->discount !== null) {
                        $currentDate = time();
                        $discountedPrice = 0;
                        if ($currentDate >= $fromDate && $currentDate <= $toDate) {
                            if ($c_product->discount->limited == 0) {
                                // Apply the discount without checking date range
                                $discountValue = $c_product->discount->discount_value;
                                $actualPrice = ProductClass::getOptionValue('_price', $c_product->metas);
                                $discountAmount = ($discountValue / 100) * $actualPrice;
                                $discountedPrice = $actualPrice - $discountAmount;
                            } elseif ($c_product->discount->limited == 1) {
                                // Apply the discount only if within the valid date range
                                $fromDate = strtotime($c_product->discount->from_date);
                                $toDate = strtotime($c_product->discount->end_date);
                                $discountValue = $c_product->discount->discount_value;
                                $actualPrice = ProductClass::getOptionValue('_price', $c_product->metas);
                                $discountAmount = ($discountValue / 100) * $actualPrice;
                                $discountedPrice = $actualPrice - $discountAmount;
                            }
                        } else {
                            // Discount is not applicable, use original price
                            $discountedPrice = ProductClass::getOptionValue('_price', $c_product->metas);
                        }
                    }

                    if (isset($c_product) && $currentDate >= $fromDate && $currentDate <= $toDate) {
                        $html .= '<div class="col-lg-2 col-md-4 col-sm-12 col-border-top-r">
                        <div class="product-detail-section">
                            <div class="card product-card">
                                <div class="card-body">
                                    <div class="product-back-img">
                                        <div class="image-container" style="background-image: url(\'' . url('/') . '/' . $c_product->featured_image . '\');"></div>';
                        $collection_products = DB::table('collection_products')
                            ->join('collections', 'collections.id', '=', 'collection_products.collection_id')
                            ->join('discounts', 'discounts.id', '=', 'collections.discount_id')
                            ->where('product_id', $c_product->id)
                            ->first();

                        if ($c_product->discount_id == 0) {
                            if ($collection_products) {
                                if ($collection_products->discount_type == 1) {
                                    $html .= '<p class="product-discount">Save ' . $collection_products->discount_value . '$ </p>';
                                } else {
                                    $html .= '<p class="product-discount">Save ' . $collection_products->discount_value . ' %</p>';
                                }
                            } else {
                                $html .= '<p class="product-discount-dynamic">Save 0</p>';
                            }
                        } else {
                            if ($c_product->discount != null) {
                                if ($c_product->discount->discount_type == 1) {
                                    $html .= '<p class="product-discount">Save ' . $c_product->discount->discount_value . ' $</p>';
                                } else {
                                    $html .= '<p class="product-discount">Save ' . $c_product->discount->discount_value . '%</p>';
                                }
                            } else {
                                $html .= '<p class="product-discount-dynamic">Save 0</p>';
                            }
                        }
                        $html .= '</div>
                                    <div class="product-details">
                                        <a class="product-detail-desc texttracate" href="' . url('/') . '/product/' . $c_product->permalink . '">' . $c_product->title . '</a>
                                        <p><span class="product-detail-amount">$';

                        $discountedPriceHtml = '';

                        if ($c_product->discount_id == 0) {

                            if ($collection_products) {

                                if ($collection_products->discount_type == 1) {
                                    $discountedPriceHtml .= intval(ProductClass::getOptionValue('_price', $c_product->metas) - ($collection_products->discount_value ?? 0));
                                } else {
                                    $discountedPriceHtml .= number_format(ProductClass::getOptionValue('_price', $c_product->metas) - (ProductClass::getOptionValue('_price', $c_product->metas) * ($collection_products->discount_value ?? 0) / 100), 2);
                                }
                            } else {
                                $discountedPriceHtml .= intval(ProductClass::getOptionValue('_price', $c_product->metas) - ($collection_products->discount_value ?? 0));
                            }
                        } else {
                            if ($c_product->discount != null) {
                                if ($c_product->discount->discount_type == 1) {
                                    $discountedPriceHtml .= intval(ProductClass::getOptionValue('_price', $c_product->metas) - ($c_product->discount->discount_value ?? 0));
                                } else {
                                    $discountedPriceHtml .= number_format(ProductClass::getOptionValue('_price', $c_product->metas) - (ProductClass::getOptionValue('_price', $c_product->metas) * ($c_product->discount->discount_value ?? 0) / 100), 2);
                                }
                            } else {
                                $discountedPriceHtml .= number_format(ProductClass::getOptionValue('_price', $c_product->metas) - (ProductClass::getOptionValue('_price', $c_product->metas) * ($c_product->discount->discount_value ?? 0) / 100), 2);
                            }
                        }
                        $html .= $discountedPriceHtml . '</span><small class="product-detail-discount"><del>$' . ProductClass::getOptionValue('_price', $c_product->metas) . '</del></small></p>
                                    </div>
                                    <div class="product-detail-addtocart-btn">
                                        <a class="TextDecor">
                                            <button class="btn futured-product-add-tocart-btn"
                                                    data-gst="' . ProductClass::getOptionValue('_gst', $c_product->metas) . '"
                                                    data-title="' . $c_product->title . '"
                                                    data-amount="' . $discountedPriceHtml . '"
                                                    data-p_id="' . $c_product->id . '"
                                                    data-featured_image="' . url('/') . '/' . $c_product->featured_image . '">
                                                Add to Cart
                                            </button>
                                        </a>
                                    </div>
                                    <div class="product-detail-tags">';
                        if ($c_product->discount_id == 0) {
                            $badgeText = $collection_products->badge_text ?? '';
                            $badgeColor = $collection_products->badge_color ?? '';
                            $imagePaths = explode(',', ($collection_products->badge_image ?? ''));

                            foreach ($imagePaths as $imagePath) {
                                if (!empty($imagePath)) {
                                    $html .= '<img src="' . asset($imagePath) . '" class="m-1" alt="">';
                                }
                            }

                            $textPaths = explode(',', $badgeText);
                            foreach ($textPaths as $textPath) {
                                if (!empty($textPath) && $textPath !== "") {
                                    $html .= '<a style="border: 2px solid ' . $badgeColor . '; color: ' . $badgeColor . ';">' . $textPath . '</a>';
                                } else {
                                    $badgeColor = isset($c_product->discount) ? $c_product->discount->badge_color : '';
                                    $html .= '';
                                }
                            }
                        } else {
                            $badge_text = isset($collection_products) ? $collection_products->badge_text : '';
                            $textPaths = explode(',', $badge_text);
                            $image_badge = isset($c_product->discount) ? $c_product->discount->badge_image : '';
                            $imagePaths = explode(',', $image_badge);
                            foreach ($textPaths as $textPath) {
                                if (!empty($textPaths) && $textPath !== "") {
                                    $badgeColor = isset($c_product->discount) ? $c_product->discount->badge_color : '';
                                    $html .= '<a style="border: 2px solid ' . $badgeColor . '; color: ' . $badgeColor . ';">' . implode(', ', $textPaths) . '</a>';
                                } else {
                                    $badgeColor = isset($c_product->discount) ? $c_product->discount->badge_color : '';
                                    $html .= '';
                                }
                            }
                            foreach ($imagePaths as $imagePath) {
                                if (!empty($imagePath)) {
                                    $html .= '<img src="' . asset($imagePath) . '" class="m-1" alt="">';
                                }
                            }
                        }
                        $html .= '</div>
                                </div>
                            </div>
                        </div>
                    </div>';
                    }
                }
            } else {
                $html .= '<div class="text-center"><p class="text-danger" style="font-size: 16px; font-weight: bold;">Sorry No Product Found in this collection.</p></div>';
            }
        }

        if ($request->ajax()) {
            return response()->json(['html' => $html]);
        }
    }
}
